@@ -20,9 +20,10 @@ LiteralTypeWrapper = type[TypedInDumps] | Callable[[dict | list | str | float |
 
 
 class TypedJsonParser:
-    def __init__(self, literal_type_wrapper: LiteralTypeWrapper = lambda x: x):
+    def __init__(self, literal_type_wrapper: LiteralTypeWrapper = lambda x: x, skip_unknown_t: bool = False):
         self._literal_type_wrapper = literal_type_wrapper
         self._wrap_literal = self._prepare_wrap_literal()
+        self.skip_unknown_t = skip_unknown_t
 
     def _prepare_wrap_literal(self) -> Callable[[dict | list | str | float | int | bool | None], Any]:
         if not isinstance(self._literal_type_wrapper, type) or not issubclass(self._literal_type_wrapper, TypedInDumps):
@@ -69,21 +70,24 @@ class TypedJsonParser:
                 try:
                     type_ = prefixed_name_to_non_abstract_type[type_name]  # TODO add some kind of skip for unknown
                 except KeyError as e:
-                    raise KeyError(
-                        f"required {target_type.__name__}({list(prefixed_name_to_non_abstract_type)}), "
-                        f"got: {type_name}") from e
-
-                kwargs = {}
-                for key, field in get_dataclass_field_name_to_field(type_).items():
-                    val = value.get(key, NoValue) if field.init else NoValue
-                    if val is NoValue:
-                        if dataclasses.is_dataclass(field.type):
-                            val = self.parse({}, field.type)
+                    if not self.skip_unknown_t:
+                        raise KeyError(
+                            f"required {target_type.__name__}({list(prefixed_name_to_non_abstract_type)}), "
+                            f"got: {type_name}") from e
                     else:
-                        val = self.parse(val, field.type)
-                    if val is not NoValue:
-                        kwargs[key] = val
-                return type_(**kwargs)
+                        pass
+                else:
+                    kwargs = {}
+                    for key, field in get_dataclass_field_name_to_field(type_).items():
+                        val = value.get(key, NoValue) if field.init else NoValue
+                        if val is NoValue:
+                            if dataclasses.is_dataclass(field.type):
+                                val = self.parse({}, field.type)
+                        else:
+                            val = self.parse(val, field.type)
+                        if val is not NoValue:
+                            kwargs[key] = val
+                    return type_(**kwargs)
             return self.parse(value, self._literal_type_wrapper)
 
         target_type_origin = getattr(target_type, '__origin__', None)
@@ -92,14 +96,19 @@ class TypedJsonParser:
         if isinstance(target_type, types.UnionType):
             if is_instance(value, target_type_args):
                 return value
-            possible_type_to_exception_text = {}
+            possible_type_to_exception_description = {}
             for possible_type in target_type_args:
                 try:
                     return self.parse(value, possible_type)
                 except (KeyError, ValueError, TypeError, AssertionError) as e:
-                    possible_type_to_exception_text[possible_type] = repr(e)
+                    description = list(e.args)
+                    if len(description) == 1:
+                        description = first(description)
+                    if not description:
+                        description = type(e).__name__
+                    possible_type_to_exception_description[str(possible_type)] = description
                     continue
-            raise ValueError(f"failed all attempts to cast {value!r}: {possible_type_to_exception_text!r}")
+            raise ValueError(f"failed all attempts to cast {value!r}", possible_type_to_exception_description)
 
         if target_type_origin is list:
             assert isinstance(value, list), f"Value is not a list: {type(value).__name__}"
